# Copyright 2016 Hewlett Packard Enterprise Development Company, L.P.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from oslo_config import cfg
from oslo_log import log as logging

from designate.scheduler import base
from designate import central

LOG = logging.getLogger(__name__)

scheduler_opts = [
    cfg.ListOpt(
        'scheduler_filters',
        default=['default_pool'],
        help='Enabled Pool Scheduling filters'),
]

cfg.CONF.register_group(central.central_group)
cfg.CONF.register_opts(scheduler_opts, group=central.central_group)


def get_scheduler(storage):
    return base.Scheduler(storage=storage)
